==> camel-test-spring-3.6.0-sources.jar: org/apache/camel/test/spring/MockEndpoints.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.spring;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.apache.camel.impl.engine.InterceptSendToMockEndpointStrategy;

/**
 * Triggers the auto-mocking of endpoints whose URIs match the provided filter. The default filter is "*" which matches
 * all endpoints. See {@link InterceptSendToMockEndpointStrategy} for more details on the registration of the mock
 * endpoints.
 */
@Documented
@Inherited
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.TYPE })
public @interface MockEndpoints {

    /**
     * The pattern to use for matching endpoints to enable mocking on.
     */
    String value() default "*";
}

==> camel-test-spring-3.20.2-sources.jar: org/apache/camel/test/spring/MockEndpoints.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.spring;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.apache.camel.component.mock.InterceptSendToMockEndpointStrategy;

/**
 * Triggers the auto-mocking of endpoints whose URIs match the provided filter. The default filter is "*" which matches
 * all endpoints. See {@link InterceptSendToMockEndpointStrategy} for more details on the registration of the mock
 * endpoints.
 */
@Documented
@Inherited
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.TYPE })
@Deprecated
public @interface MockEndpoints {

    /**
     * The pattern to use for matching endpoints to enable mocking on.
     */
    String value() default "*";
}
